@@ -31,7 +31,9 @@ class RpcExchangerRpcHandler:
 
     def __getattr__(self, service: str) -> Callable[..., Awaitable[Any]]:
         async def func(**data):
-            return await self._exchanger.rpc_request(service, data)
+            result = await self._exchanger.rpc_request(service, data)
+            log.debug(f"{result=}")
+            return result
         return func
 
 class RpcExchanger:
@@ -65,10 +67,12 @@ class RpcExchanger:
         self._sock.close()
 
     async def send_msg(self, username: str, msg: str, chat: int) -> None:
+        log.debug(f"messages:{chat}")
         await self._redis.publish(f"messages:{chat}", json.dumps({
             "username": username,
             "msg": msg
         }))
+        log.debug(f"{username=} {msg=} {chat=}")
 
     async def rpc_request(self, service: str, data: Any) -> Any:
         loop = asyncio.get_event_loop()
@@ -79,6 +83,7 @@ class RpcExchanger:
                 "data": data,
                 "jobid": self._jobid
             }).encode())
+            log.debug(f"{service=} {data=}")
             self._jobid = json.loads((await loop.sock_recv(self._sock, 65536)).decode())["next_jobid"]
             return json.loads((await loop.sock_recv(self._sock, 65536)).decode())["data"]
 
@@ -131,15 +136,16 @@ class RpcExchangerClient:
         msg = ""
         chat = -1
         while raw_message is None:
-            if not self._chat_list:
+            while not self._chat_list:
                 await asyncio.sleep(1000)
-                continue
             raw_message = await self._pubsub.get_message(ignore_subscribe_messages=True)
+            logging.debug(f"{raw_message['data']=} {raw_message['channel']=}")
             try:
                 json_content = json.loads(raw_message["data"].decode())
                 username = json_content["username"]
                 msg = json_content["msg"]
                 chat = int(raw_message["channel"][9:])
+                logging.debug(f"{username=} {msg=} {chat=}")
                 if ignore_self_messages and username == self._username:
                     raw_message = None
             except:
@@ -164,6 +170,7 @@ class RpcExchangerClient:
             raise ChatAlreadyJoinedError()
         if not await self._rpc.chat_join(chat_id=id, user_id=self._uid):
             raise UnknownError()
+        log.debug(f"messages:{id}")
         await self._pubsub.subscribe(f"messages:{id}")
         self._chat_list.add(id)
     
@@ -173,6 +180,7 @@ class RpcExchangerClient:
             raise ChatNotJoinedError()
         if not await self._rpc.chat_quit(chat_id=id, user_id=self._uid):
             raise UnknownError()
+        log.debug(f"messages:{id}")
         await self._pubsub.unsubscribe(f"messages:{id}")
         self._chat_list.remove(id)
 
